@@ -1,4 +1,4 @@
-from composio import Action, App, Tag, Trigger, WorkspaceType
+from composio import Action, App, Tag, Trigger, WorkspaceType, action
 
 from composio_griptape.toolset import ComposioToolSet
 
@@ -8,6 +8,7 @@ __all__ = (
     "App",
     "Tag",
     "WorkspaceType",
+    "action",
     "Trigger",
     "ComposioToolSet",
 )
